@@ -2,19 +2,11 @@ module Enumerize
   module Base
     def self.included(base)
       base.extend ClassMethods
+      base.singleton_class.prepend ClassMethods::Hook
 
       if base.respond_to?(:validate)
         base.validate :_validate_enumerized_attributes
       end
-
-      class << base
-        if (method_defined?(:inherited) || private_method_defined?(:inherited)) && !private_method_defined?(:inherited_without_enumerized)
-          alias_method :inherited_without_enumerized, :inherited
-          private :inherited_without_enumerized
-        end
-
-        alias_method :inherited, :inherited_with_enumerized
-      end
     end
 
     module ClassMethods
@@ -37,10 +29,10 @@ module Enumerize
         @enumerized_attributes ||= AttributeMap.new
       end
 
-      def inherited_with_enumerized(subclass)
-        enumerized_attributes.add_dependant subclass.enumerized_attributes
-        if respond_to?(:inherited_without_enumerized, true)
-          inherited_without_enumerized subclass
+      module Hook
+        def inherited(subclass)
+          enumerized_attributes.add_dependant subclass.enumerized_attributes
+          super subclass
         end
       end
 
@@ -93,22 +85,26 @@ module Enumerize
 
     def _set_default_value_for_enumerized_attributes
       self.class.enumerized_attributes.each do |attr|
-        if respond_to?(attr.name)
-          attr_value = public_send(attr.name)
-        else
-          next
-        end
-
-        value_for_validation = _enumerized_values_for_validation[attr.name.to_s]
-
-        if (!attr_value || attr_value.empty?) && (!value_for_validation || value_for_validation.empty?)
-          value = attr.default_value
-
-          if value.respond_to?(:call)
-            value = value.arity == 0 ? value.call : value.call(self)
+        next if attr.default_value.nil?
+        begin
+          if respond_to?(attr.name)
+            attr_value = public_send(attr.name)
+          else
+            next
           end
 
-          public_send("#{attr.name}=", value)
+          value_for_validation = _enumerized_values_for_validation[attr.name.to_s]
+
+          if (!attr_value || attr_value.empty?) && (!value_for_validation || value_for_validation.empty?)
+            value = attr.default_value
+
+            if value.respond_to?(:call)
+              value = value.arity == 0 ? value.call : value.call(self)
+            end
+
+            public_send("#{attr.name}=", value)
+          end
+        rescue ActiveModel::MissingAttributeError
         end
       end
     end
