@@ -3,14 +3,10 @@ require 'active_support/concern'
 module Enumerize
   module Hooks
     module FormtasticFormBuilderExtension
-      extend ActiveSupport::Concern
 
-      included do
-        alias_method_chain :input, :enumerize
-      end
-
-      def input_with_enumerize(method, options={})
-        klass = object.class
+      def input(method, options={})
+        enumerized_object = convert_to_model(object)
+        klass = enumerized_object.class
 
         if klass.respond_to?(:enumerized_attributes) && (attr = klass.enumerized_attributes[method])
           options[:collection] ||= attr.options
@@ -20,10 +16,10 @@ module Enumerize
           end
         end
 
-        input_without_enumerize(method, options)
+        super(method, options)
       end
     end
   end
 end
 
-::Formtastic::FormBuilder.send :include, Enumerize::Hooks::FormtasticFormBuilderExtension
+::Formtastic::FormBuilder.send :prepend, Enumerize::Hooks::FormtasticFormBuilderExtension
